/*
 *  survAUC_HZ.h
 *  Daim
 *
 *  Created by Sergej Potapov on 22.06.10.
 *  Copyright 2010 __IMBE__. All rights reserved.
 *
 */

void C_cox_weights (double *marker, double *time, int *status, double *target, double *AUC, int *N_st);
